      SUBROUTINE INTERX (NIND,TABLE,VAR,LENGTH,DEP,ANS,LIND,LDEP,
     1           LX1L,LX2L,LX3L,LX4L,LX1U,LX2U,LX3U,LX4U,MESS,NMSS,ROUT)
C
C
C  THE PURPOSE OF THIS SUBROUTINE IS TO PERFORM A LINEAR INTERPOLATION
C  FOR UP TO FOUR INDEPENDENT VARIABLES.  A TABLE LOOK-UP IS PERFORMED
C  PRIOR TO THE INTERPOLATION IN ORDER TO FIND THE TABLE VALUES BOUNDING
C  EACH OF THE INDEPENDENT VARIABLES.
C
C  THE CALLING FORMAT FOR THIS SUBROUTINE IS
C         CALL INTERP(NIND,TABLE,VAR,LENGTH,DEP,ANS,LIND,LDEP)
C
C     WHERE,
C            NIND  = NUMBER OF INDEPENDENT VARIABLES
C            TABLE = TABLE NAMES OF THE INDEPENDENT VARIABLES (1-N,1-4)
C            VAR   = INDEPENDENT VARIABLE VALUES (1-4)
C            LENGTH= LENGTH OF INDEPENDENT VARIABLE TABLES (1-4)
C            DEP   = DEPENDENT VARIABLE TABLE NAME
C            ANS   = INTERPOLATION RESULT
C           LIND  = LENGTH OF THE LARGEST INDEPENDENT VARIABLE TABLE
C                   FOR A GIVEN INDEPENDENT VARIABLE TABLE NAME
C           LDEP  = LENGTH OF THE DEPENDENT VARIABLE TABLE
C
C  THE FUNCTION VALUES OF THE DEPENDENT VARIABLE ARE IN THE FOLLOWING
C  MANNER
C       ASSUME X,Y, AND Z ARE THE INDEPENDENT VARIABLES WITH THE
C       CORRESPONDING TABLE LENGTHS OF X=4, Y=3, AND Z=2.  THE
C       DEPENDENT VARIABLE TABLE THEN MUST BE
C           DEP(1) = F(X1,Y1,Z1)       DEP(13)= F(X1,Y1,Z2)
C           DEP(2) = F(X2,Y1,Z1)       DEP(14)= F(X2,Y1,Z2)
C           DEP(3) = F(X3,Y1,Z1)       DEP(15)= F(X3,Y1,Z2)
C           DEP(4) = F(X4,Y1,Z1)       DEP(16)= F(X4,Y1,Z2)
C           DEP(5) = F(X1,Y2,Z1)       DEP(17)= F(X1,Y2,Z2)
C           DEP(6) = F(X2,Y2,Z1)       DEP(18)= F(X2,Y2,Z2)
C           DEP(7) = F(X3,Y2,Z1)       DEP(19)= F(X3,Y2,Z2)
C           DEP(8) = F(X4,Y2,Z1)       DEP(20)= F(X4,Y2,Z2)
C           DEP(9) = F(X1,Y3,Z1)       DEP(21)= F(X1,Y3,Z2)
C           DEP(10)= F(X2,Y3,Z1)       DEP(22)= F(X2,Y3,Z2)
C           DEP(11)= F(X3,Y3,Z1)       DEP(23)= F(X3,Y3,Z2)
C           DEP(12)= F(X4,Y3,Z1)       DEP(24)= F(X4,Y3,Z2)
      DIMENSION MSSCL(21),RMSCL(21)
      DIMENSION LENGTH(4),TABLE(LIND,4),DEP(LDEP),VAR(4),ROUT(2),
     1          MESS(20)
      EQUIVALENCE(MSSCL(1),RMSCL(1))
      DATA MSSCL  /4HINTE,4HRX  ,19*0/
      DATA SRPMSS /4H1TIN/,HOL1/4H1EXP/
C
C     ----SUPPRESS TLINNX S MESSAGES.
C
      RO=SRPMSS
      GO TO (1000,1010,1020,1030),NIND
C
 1000 CALL TLIN1X(TABLE,DEP,LENGTH,VAR,ANS,LX1L,LX1U,MESS,NMSS,RO)
      GO TO 1040
 1010 CALL TLINEX(TABLE(1,2),TABLE(1,1),DEP,LENGTH(2),LENGTH(1),VAR(2),
     1            VAR(1),ANS,LX2L,LX1L,LX2U,LX1U,MESS,NMSS,RO)
      GO TO 1040
 1020 CALL TLIN3X(TABLE(1,2),TABLE(1,1),TABLE(1,3),DEP,LENGTH(2),
     1            LENGTH(1),LENGTH(3),VAR(2),VAR(1),VAR(3),ANS,LX2L,
     2            LX1L,LX3L,LX2U,LX1U,LX3U,MESS,NMSS,RO)
      GO TO 1040
C
C****TLIN4X CALL DELETED TO SAVE CORE****
C
 1030 CONTINUE
C1400 CALL TLIN4X(TABLE(1,2),TABLE(1,1),TABLE(1,3),TABLE(1,4),DEP,LENGTH
C    1(2),LENGTH(1),LENGTH(3),LENGTH(4),VAR(2),VAR(1),VAR(3),VAR(4),ANS,
C    2LX2L,LX1L,LX3L,LX4L,LX2U,LX1U,LX3U,LX4U,MESS,NMSS,RO)
C**** END OF DELETION****
C
C     ----PRINT MESSAGE IF REQUIRED
C
 1040 IF(RO.NE.HOL1)RETURN
      MSSCL(3)=NMSS
      RMSCL(4)=ANS
      MSSCL(5)=NIND
      L=6
      MSSCL(8)=LX1L
      MSSCL(9)=LX1U
      MSSCL(12)=LX2L
      MSSCL(13)=LX2U
      MSSCL(16)=LX3L
      MSSCL(17)=LX3U
      MSSCL(20)=LX4L
      MSSCL(21)=LX4U
      DO 1050 I=1,NIND
         RMSCL(L)=VAR(I)
         MSSCL(L+1)=LENGTH(I)
         L=L+4
 1050 CONTINUE
      CALL MESSGE(ROUT,MESS,TABLE(1,1),TABLE(1,2),TABLE(1,3),TABLE(1,4),
     1            MSSCL)
      RETURN
      END
