      SUBROUTINE SORTER(A,N,M,IROW,ICOL,B,IR,IC,IFLAG)
C
C  SUBROUTINE TO SORT A TWO DIMENSIONAL INTEGER ARRAY IN ASCENDING ORDER
C
C  INPUTS
C
C     A    - TWO DIMENSIONAL ARRAY TO BE SORTED
C     N    - NUMBER OF ROWS IN ARRAY
C     M    - NUMBER OF COLUMNS IN ARRAY
C     IROW - IF NON-ZERO, SORT ARRAY BASED ON VALUES IN ROW IROW
C     ICOL - IF NON-ZERO, SORT ARRAY BASED ON VALUES IN COLUMN ICOL
C
C  OUTPUTS
C
C     B    - SORTED ARRAY A
C     IR   - ARRAY ELEMENTS GIVE THE ORDER OF ROWS EXCHANGED
C     IC   - ARRAY ELEMENTS GIVE THE ORDER OF COLUMNS EXCHANGED
C     IFLAG- RETURNS A ZERO (0) FOR ARRAY SORTED,  RETURNS A ONE (1)
C            FOR NO ARRAY SORTING PERFORMED
C
C  COMMENTS
C
C     IF ICOL AND IROW ARE BOTH NON-ZERO, THE SORTING WILL BE FIRST
C     PERFORMED BY THE VALUES IN COLUMN ICOL, THEN BY THE VALUES IN
C     ROW IROW. IF THIS OPTION IS SPECIFIED, THE ORIGINAL MATRIX A
C     IS DESTROYED.  FOR A VECTOR, SET M TO ONE AND IROW TO ZERO.
C
C     THIS ROUTINE IS DESIGNED FOR INTEGER ARRAYS, BUT CAN BE
C     USED FOR FLOATING POINT ARRAYS AS WELL BY DELETING THE
C     INTEGER DECLARATION CARD THAT FOLLOWS.
C
      INTEGER A,B,BMIN,BMAX
      DIMENSION A(N,M),B(N,M),IR(N),IC(M)
      IF(N.LE.0) GO TO 1290
      IF(M.LE.0) GO TO 1290
      DO 1000 I=1,N
 1000 IR(I)=I
      DO 1010 I=1,M
 1010 IC(I)=I
      IF(N.EQ.M.AND.N.LT.2) GO TO 1300
      IFLAG=0
      IF(ICOL)1020,1020,1030
 1020 IF(IROW)1250,1250,1130
 1030 CONTINUE
C
C  SORT ARRAY BY THE VALUES IN COLUMN ICOL (REORDER ROWS)
C
      IRR=1
      KK=1
      ISTAT=0
      KOUNT=0
      DO 1040 I=1,N
         DO 1040 J=1,M
 1040 B(I,J)=A(I,J)
      BMAX=B(1,ICOL)
      BMIN=BMAX
 1050 DO 1080 K1=1,N
         K=N-K1+1
         IF(ISTAT)1060,1060,1070
 1060    IF(BMAX.LE.B(K,ICOL))BMAX=B(K,ICOL)
         IF(BMAX.EQ.B(K,ICOL))KK=K
         GO TO 1080
 1070    IF(BMIN.GE.B(K,ICOL))BMIN=B(K,ICOL)
         IF(BMIN.EQ.B(K,ICOL))KK=K
 1080 CONTINUE
      KOUNT=KOUNT+1
      IF(ISTAT)1090,1090,1100
 1090 ISTAT=1
      KOUNT=0
      KK=1
      GO TO 1050
 1100 IF(KOUNT.GE.(N+1))GO TO 1110
      B(KK,ICOL)=BMAX+BMAX
      IR(IRR)=KK
      IRR=IRR+1
      BMIN=BMAX+BMAX
      GO TO 1050
 1110 DO 1120 K=1,N
         LL=IR(K)
         DO 1120 L=1,M
            B(K,L)=A(LL,L)
 1120 CONTINUE
      IFLAG=-1
      GO TO 1020
 1130 CONTINUE
C
C  SORT ARRAY BY THE VALUES IN ROW IROW (REORDER COLUMNS)
C
      IF(IFLAG.GE.0)GO TO 1150
      DO 1140 I=1,N
         DO 1140 J=1,M
 1140 A(I,J)=B(I,J)
 1150 CONTINUE
      IRR=1
      KK=1
      ISTAT=0
      KOUNT=0
      DO 1160 I=1,N
         DO 1160 J=1,M
 1160 B(I,J)=A(I,J)
      BMAX=B(IROW,1)
      BMIN=BMAX
 1170 DO 1200 K1=1,M
         K=M-K1+1
         IF(ISTAT)1180,1180,1190
 1180    IF(BMAX.LE.B(IROW,K))BMAX=B(IROW,K)
         IF(BMAX.EQ.B(IROW,K))KK=K
         GO TO 1200
 1190    IF(BMIN.GE.B(IROW,K))BMIN=B(IROW,K)
         IF(BMIN.EQ.B(IROW,K))KK=K
 1200 CONTINUE
      KOUNT=KOUNT+1
      IF(ISTAT)1210,1210,1220
 1210 ISTAT=1
      KOUNT=0
      KK=1
      GO TO 1170
 1220 IF(KOUNT.GE.(M+1))GO TO 1230
      B(IROW,KK)=BMAX+BMAX
      IC(IRR)=KK
      IRR=IRR+1
      BMIN=BMAX+BMAX
      GO TO 1170
 1230 DO 1240 L=1,M
         LL=IC(L)
         DO 1240 K=1,N
            B(K,L)=A(K,LL)
 1240 CONTINUE
 1250 IFLAG=0
      DO 1260 I=1,N
         IF(IR(I).NE.I) GO TO 1300
 1260 CONTINUE
 1270 DO 1280 I=1,M
         IF(IC(I).NE.I) GO TO 1300
 1280 CONTINUE
 1290 IFLAG=1
 1300 CONTINUE
      RETURN
      END
